summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/tools/qtconfig
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-09 22:25:47 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-09 22:25:47 -0500
commiteaa7ee2e0bbca40ba3173c4304f81957e8964291 (patch)
tree4f793aa48a5080aedc94ce6e519c3b86708f2b88 /tqtinterface/qt4/tools/qtconfig
parent79a9d7a46a20d4a0923bc06fc471fdc2176ef865 (diff)
downloadexperimental-eaa7ee2e0bbca40ba3173c4304f81957e8964291.tar.gz
experimental-eaa7ee2e0bbca40ba3173c4304f81957e8964291.zip
rename the following methods:
tqfind find tqreplace replace tqcontains contains
Diffstat (limited to 'tqtinterface/qt4/tools/qtconfig')
-rw-r--r--tqtinterface/qt4/tools/qtconfig/LICENSE.GPL6
-rw-r--r--tqtinterface/qt4/tools/qtconfig/mainwindow.cpp16
2 files changed, 11 insertions, 11 deletions
diff --git a/tqtinterface/qt4/tools/qtconfig/LICENSE.GPL b/tqtinterface/qt4/tools/qtconfig/LICENSE.GPL
index 149f4ac..3221c03 100644
--- a/tqtinterface/qt4/tools/qtconfig/LICENSE.GPL
+++ b/tqtinterface/qt4/tools/qtconfig/LICENSE.GPL
@@ -59,7 +59,7 @@ modification follow.
GNU GENERAL PUBLIC LICENSE
TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION
- 0. This License applies to any program or other work which tqcontains
+ 0. This License applies to any program or other work which contains
a notice placed by the copyright holder saying it may be distributed
under the terms of this General Public License. The "Program", below,
refers to any such program or work, and a "work based on the Program"
@@ -96,7 +96,7 @@ above, provided that you also meet all of these conditions:
stating that you changed the files and the date of any change.
b) You must cause any work that you distribute or publish, that in
- whole or in part tqcontains or is derived from the Program or any
+ whole or in part contains or is derived from the Program or any
part thereof, to be licensed as a whole at no charge to all third
parties under the terms of this License.
@@ -154,7 +154,7 @@ Sections 1 and 2 above provided that you also do one of the following:
The source code for a work means the preferred form of the work for
making modifications to it. For an executable work, complete source
-code means all the source code for all modules it tqcontains, plus any
+code means all the source code for all modules it contains, plus any
associated interface definition files, plus the scripts used to
control compilation and installation of the executable. However, as a
special exception, the source code distributed need not include
diff --git a/tqtinterface/qt4/tools/qtconfig/mainwindow.cpp b/tqtinterface/qt4/tools/qtconfig/mainwindow.cpp
index 03c6e1d..42e7033 100644
--- a/tqtinterface/qt4/tools/qtconfig/mainwindow.cpp
+++ b/tqtinterface/qt4/tools/qtconfig/mainwindow.cpp
@@ -238,14 +238,14 @@ MainWindow::MainWindow()
if (s < gstylecombo->count()) {
gstylecombo->setCurrentItem(s);
} else {
// no predefined style, try to tqfind the closest match
// class names usually contain the name of the style, so we
// iterate over the items in the combobox, and use the one whose
// name is contained in the classname of the style
s = 0;
git = gstyles.begin();
while (git != gstyles.end()) {
- if (currentstyle.tqcontains(*git))
+ if (currentstyle.contains(*git))
break;
s++;
git++;
@@ -274,7 +274,7 @@ MainWindow::MainWindow()
TQStringList fs2 = TQT_TQSTRINGLIST_OBJECT(TQFont::substitutions());
TQStringList::Iterator fsit = fs2.begin();
while (fsit != fs2.end()) {
- if (! fs.tqcontains(*fsit))
+ if (! fs.contains(*fsit))
fs += *fsit;
fsit++;
}
@@ -318,13 +318,13 @@ MainWindow::MainWindow()
libpathlistbox->clear();
libpathlistbox->insertStringList(TQApplication::libraryPaths());
// tqfind the default family
TQStringList::Iterator sit = families.begin();
int i = 0, possible = -1;
while (sit != families.end()) {
if (*sit == TQApplication::font().family())
break;
- if ((*sit).tqcontains(TQApplication::font().family()))
+ if ((*sit).contains(TQApplication::font().family()))
possible = i;
i++;
@@ -347,7 +347,7 @@ MainWindow::MainWindow()
while (sit != styles.end()) {
if (*sit == stylestring)
break;
- if ((*sit).tqcontains(stylestring))
+ if ((*sit).contains(stylestring))
possible = i;
i++;
@@ -398,7 +398,7 @@ MainWindow::MainWindow()
// prevent to be listed in ordinary input method list.
TQStringList::Iterator imIt = inputMethodIdentifiers.begin();
while (imIt != inputMethodIdentifiers.end()) {
- if ((*imIt).tqfind("imsw-") == 0)
+ if ((*imIt).find("imsw-") == 0)
imIt = inputMethodIdentifiers.remove(imIt);
else
imIt++;
@@ -424,7 +424,7 @@ MainWindow::MainWindow()
// default input method is XIM in X11.
TQString currentIM = settings.readEntry("/qt/DefaultInputMethod", "xim");
{
- int index = inputMethodIdentifiers.tqfindIndex(currentIM);
+ int index = inputMethodIdentifiers.findIndex(currentIM);
// set up Selected input method.
if (0 <= index && index < inputMethodIdentifiers.count()) {
inputMethodCombo->setCurrentItem(index);
@@ -238,14 +238,14 @@ MainWindow::MainWindow()
gstylecombo->setCurrentItem(s);
} else {
- // no predefined style, try to tqfind the closest match
+ // no predefined style, try to find the closest match
// class names usually contain the name of the style, so we
// iterate over the items in the combobox, and use the one whose
@@ -318,13 +318,13 @@ MainWindow::MainWindow()
libpathlistbox->clear();
libpathlistbox->insertStringList(TQApplication::libraryPaths());
- // tqfind the default family
+ // find the default family
TQStringList::Iterator sit = families.begin();
int i = 0, possible = -1;